@@ -1,8 +1,8 @@
-// Copyright 2018, The Gtk-rs Project Developers.
-// See the COPYRIGHT file at the top-level directory of this distribution.
-// Licensed under the MIT license, see the LICENSE file or <http://opensource.org/licenses/MIT>
+// Take a look at the license at the top of the repository in the LICENSE file.
+#![cfg_attr(feature = "dox", feature(doc_cfg))]
+// Re-export -sys
+pub use ffi;
 
-/// Asserts that this is the main thread and `gtk::init` has been called.
 macro_rules! assert_initialized_main_thread {
     () => {
         if !::gtk::is_initialized_main_thread() {
@@ -19,14 +19,15 @@ macro_rules! skip_assert_initialized {
     () => {};
 }
 
-pub mod prelude;
-
+#[allow(clippy::clone_on_copy)]
+#[allow(clippy::let_and_return)]
+#[allow(clippy::type_complexity)]
+#[allow(unused_doc_comments)]
 #[allow(unused_imports)]
 mod auto;
 pub use auto::*;
 
-mod completion;
-mod completion_info;
-mod gutter_renderer;
-mod search_context;
+mod gutter_lines;
 mod view;
+
+pub mod prelude;
